# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class Exception(object):
    """Describes a runtime exception encountered during the execution of an analysis tool."""

    inner_exceptions = attr.ib(default=None, metadata={"schema_property_name": "innerExceptions"})
    kind = attr.ib(default=None, metadata={"schema_property_name": "kind"})
    message = attr.ib(default=None, metadata={"schema_property_name": "message"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    stack = attr.ib(default=None, metadata={"schema_property_name": "stack"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class PhysicalLocation(object):
    """A physical location relevant to a result. Specifies a reference to a programming artifact together with a range of bytes or characters within that artifact."""

    address = attr.ib(default=None, metadata={"schema_property_name": "address"})
    artifact_location = attr.ib(default=None, metadata={"schema_property_name": "artifactLocation"})
    context_region = attr.ib(default=None, metadata={"schema_property_name": "contextRegion"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    region = attr.ib(default=None, metadata={"schema_property_name": "region"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class ConfigurationOverride(object):
    """Information about how a specific rule or notification was reconfigured at runtime."""

    configuration = attr.ib()
    descriptor = attr.ib()
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class Invocation(object):
    """The runtime environment of the analysis tool run."""

    execution_successful = attr.ib()
    account = attr.ib(default=None, metadata={"schema_property_name": "account"})
    arguments = attr.ib(default=None, metadata={"schema_property_name": "arguments"})
    command_line = attr.ib(default=None, metadata={"schema_property_name": "commandLine"})
    end_time_utc = attr.ib(default=None, metadata={"schema_property_name": "endTimeUtc"})
    environment_variables = attr.ib(default=None, metadata={"schema_property_name": "environmentVariables"})
    executable_location = attr.ib(default=None, metadata={"schema_property_name": "executableLocation"})
    exit_code = attr.ib(default=None, metadata={"schema_property_name": "exitCode"})
    exit_code_description = attr.ib(default=None, metadata={"schema_property_name": "exitCodeDescription"})
    exit_signal_name = attr.ib(default=None, metadata={"schema_property_name": "exitSignalName"})
    exit_signal_number = attr.ib(default=None, metadata={"schema_property_name": "exitSignalNumber"})
    machine = attr.ib(default=None, metadata={"schema_property_name": "machine"})
    notification_configuration_overrides = attr.ib(default=None, metadata={"schema_property_name": "notificationConfigurationOverrides"})
    process_id = attr.ib(default=None, metadata={"schema_property_name": "processId"})
    process_start_failure_message = attr.ib(default=None, metadata={"schema_property_name": "processStartFailureMessage"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    response_files = attr.ib(default=None, metadata={"schema_property_name": "responseFiles"})
    rule_configuration_overrides = attr.ib(default=None, metadata={"schema_property_name": "ruleConfigurationOverrides"})
    start_time_utc = attr.ib(default=None, metadata={"schema_property_name": "startTimeUtc"})
    stderr = attr.ib(default=None, metadata={"schema_property_name": "stderr"})
    stdin = attr.ib(default=None, metadata={"schema_property_name": "stdin"})
    stdout = attr.ib(default=None, metadata={"schema_property_name": "stdout"})
    stdout_stderr = attr.ib(default=None, metadata={"schema_property_name": "stdoutStderr"})
    tool_configuration_notifications = attr.ib(default=None, metadata={"schema_property_name": "toolConfigurationNotifications"})
    tool_execution_notifications = attr.ib(default=None, metadata={"schema_property_name": "toolExecutionNotifications"})
    working_directory = attr.ib(default=None, metadata={"schema_property_name": "workingDirectory"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class PropertyBag(object):
    """Key/value pairs that provide additional information about the object."""

    tags = attr.ib(default=None, metadata={"schema_property_name": "tags"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class ReportingDescriptorRelationship(object):
    """Information about the relation of one reporting descriptor to another."""

    target = attr.ib()
    description = attr.ib(default=None, metadata={"schema_property_name": "description"})
    kinds = attr.ib(default=['relevant'], metadata={"schema_property_name": "kinds"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class Region(object):
    """A region within an artifact where a result was detected."""

    byte_length = attr.ib(default=None, metadata={"schema_property_name": "byteLength"})
    byte_offset = attr.ib(default=-1, metadata={"schema_property_name": "byteOffset"})
    char_length = attr.ib(default=None, metadata={"schema_property_name": "charLength"})
    char_offset = attr.ib(default=-1, metadata={"schema_property_name": "charOffset"})
    end_column = attr.ib(default=None, metadata={"schema_property_name": "endColumn"})
    end_line = attr.ib(default=None, metadata={"schema_property_name": "endLine"})
    message = attr.ib(default=None, metadata={"schema_property_name": "message"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    snippet = attr.ib(default=None, metadata={"schema_property_name": "snippet"})
    source_language = attr.ib(default=None, metadata={"schema_property_name": "sourceLanguage"})
    start_column = attr.ib(default=None, metadata={"schema_property_name": "startColumn"})
    start_line = attr.ib(default=None, metadata={"schema_property_name": "startLine"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class Edge(object):
    """Represents a directed edge in a graph."""

    id = attr.ib()
    source_node_id = attr.ib()
    target_node_id = attr.ib()
    label = attr.ib(default=None, metadata={"schema_property_name": "label"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class StackFrame(object):
    """A function call within a stack trace."""

    location = attr.ib(default=None, metadata={"schema_property_name": "location"})
    module = attr.ib(default=None, metadata={"schema_property_name": "module"})
    parameters = attr.ib(default=None, metadata={"schema_property_name": "parameters"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    thread_id = attr.ib(default=None, metadata={"schema_property_name": "threadId"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class Run(object):
    """Describes a single run of an analysis tool, and contains the reported output of that run."""

    tool = attr.ib()
    addresses = attr.ib(default=None, metadata={"schema_property_name": "addresses"})
    artifacts = attr.ib(default=None, metadata={"schema_property_name": "artifacts"})
    automation_details = attr.ib(default=None, metadata={"schema_property_name": "automationDetails"})
    baseline_guid = attr.ib(default=None, metadata={"schema_property_name": "baselineGuid"})
    column_kind = attr.ib(default=None, metadata={"schema_property_name": "columnKind"})
    conversion = attr.ib(default=None, metadata={"schema_property_name": "conversion"})
    default_encoding = attr.ib(default=None, metadata={"schema_property_name": "defaultEncoding"})
    default_source_language = attr.ib(default=None, metadata={"schema_property_name": "defaultSourceLanguage"})
    external_property_file_references = attr.ib(default=None, metadata={"schema_property_name": "externalPropertyFileReferences"})
    graphs = attr.ib(default=None, metadata={"schema_property_name": "graphs"})
    invocations = attr.ib(default=None, metadata={"schema_property_name": "invocations"})
    language = attr.ib(default="en-US", metadata={"schema_property_name": "language"})
    logical_locations = attr.ib(default=None, metadata={"schema_property_name": "logicalLocations"})
    newline_sequences = attr.ib(default=['\r\n', '\n'], metadata={"schema_property_name": "newlineSequences"})
    original_uri_base_ids = attr.ib(default=None, metadata={"schema_property_name": "originalUriBaseIds"})
    policies = attr.ib(default=None, metadata={"schema_property_name": "policies"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    redaction_tokens = attr.ib(default=None, metadata={"schema_property_name": "redactionTokens"})
    results = attr.ib(default=None, metadata={"schema_property_name": "results"})
    run_aggregates = attr.ib(default=None, metadata={"schema_property_name": "runAggregates"})
    special_locations = attr.ib(default=None, metadata={"schema_property_name": "specialLocations"})
    taxonomies = attr.ib(default=None, metadata={"schema_property_name": "taxonomies"})
    thread_flow_locations = attr.ib(default=None, metadata={"schema_property_name": "threadFlowLocations"})
    translations = attr.ib(default=None, metadata={"schema_property_name": "translations"})
    version_control_provenance = attr.ib(default=None, metadata={"schema_property_name": "versionControlProvenance"})
    web_requests = attr.ib(default=None, metadata={"schema_property_name": "webRequests"})
    web_responses = attr.ib(default=None, metadata={"schema_property_name": "webResponses"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class Suppression(object):
    """A suppression that is relevant to a result."""

    kind = attr.ib()
    guid = attr.ib(default=None, metadata={"schema_property_name": "guid"})
    justification = attr.ib(default=None, metadata={"schema_property_name": "justification"})
    location = attr.ib(default=None, metadata={"schema_property_name": "location"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    state = attr.ib(default=None, metadata={"schema_property_name": "state"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class ToolComponentReference(object):
    """Identifies a particular toolComponent object, either the driver or an extension."""

    guid = attr.ib(default=None, metadata={"schema_property_name": "guid"})
    index = attr.ib(default=-1, metadata={"schema_property_name": "index"})
    name = attr.ib(default=None, metadata={"schema_property_name": "name"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class RunAutomationDetails(object):
    """Information that describes a run's identity and role within an engineering system process."""

    correlation_guid = attr.ib(default=None, metadata={"schema_property_name": "correlationGuid"})
    description = attr.ib(default=None, metadata={"schema_property_name": "description"})
    guid = attr.ib(default=None, metadata={"schema_property_name": "guid"})
    id = attr.ib(default=None, metadata={"schema_property_name": "id"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class ExternalPropertyFileReferences(object):
    """References to external property files that should be inlined with the content of a root log file."""

    addresses = attr.ib(default=None, metadata={"schema_property_name": "addresses"})
    artifacts = attr.ib(default=None, metadata={"schema_property_name": "artifacts"})
    conversion = attr.ib(default=None, metadata={"schema_property_name": "conversion"})
    driver = attr.ib(default=None, metadata={"schema_property_name": "driver"})
    extensions = attr.ib(default=None, metadata={"schema_property_name": "extensions"})
    externalized_properties = attr.ib(default=None, metadata={"schema_property_name": "externalizedProperties"})
    graphs = attr.ib(default=None, metadata={"schema_property_name": "graphs"})
    invocations = attr.ib(default=None, metadata={"schema_property_name": "invocations"})
    logical_locations = attr.ib(default=None, metadata={"schema_property_name": "logicalLocations"})
    policies = attr.ib(default=None, metadata={"schema_property_name": "policies"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    results = attr.ib(default=None, metadata={"schema_property_name": "results"})
    taxonomies = attr.ib(default=None, metadata={"schema_property_name": "taxonomies"})
    thread_flow_locations = attr.ib(default=None, metadata={"schema_property_name": "threadFlowLocations"})
    translations = attr.ib(default=None, metadata={"schema_property_name": "translations"})
    web_requests = attr.ib(default=None, metadata={"schema_property_name": "webRequests"})
    web_responses = attr.ib(default=None, metadata={"schema_property_name": "webResponses"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class ResultProvenance(object):
    """Contains information about how and when a result was detected."""

    conversion_sources = attr.ib(default=None, metadata={"schema_property_name": "conversionSources"})
    first_detection_run_guid = attr.ib(default=None, metadata={"schema_property_name": "firstDetectionRunGuid"})
    first_detection_time_utc = attr.ib(default=None, metadata={"schema_property_name": "firstDetectionTimeUtc"})
    invocation_index = attr.ib(default=-1, metadata={"schema_property_name": "invocationIndex"})
    last_detection_run_guid = attr.ib(default=None, metadata={"schema_property_name": "lastDetectionRunGuid"})
    last_detection_time_utc = attr.ib(default=None, metadata={"schema_property_name": "lastDetectionTimeUtc"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class SpecialLocations(object):
    """Defines locations of special significance to SARIF consumers."""

    display_base = attr.ib(default=None, metadata={"schema_property_name": "displayBase"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class Node(object):
    """Represents a node in a graph."""

    id = attr.ib()
    children = attr.ib(default=None, metadata={"schema_property_name": "children"})
    label = attr.ib(default=None, metadata={"schema_property_name": "label"})
    location = attr.ib(default=None, metadata={"schema_property_name": "location"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class ToolComponent(object):
    """A component, such as a plug-in or the driver, of the analysis tool that was run."""

    name = attr.ib()
    associated_component = attr.ib(default=None, metadata={"schema_property_name": "associatedComponent"})
    contents = attr.ib(default=['localizedData', 'nonLocalizedData'], metadata={"schema_property_name": "contents"})
    dotted_quad_file_version = attr.ib(default=None, metadata={"schema_property_name": "dottedQuadFileVersion"})
    download_uri = attr.ib(default=None, metadata={"schema_property_name": "downloadUri"})
    full_description = attr.ib(default=None, metadata={"schema_property_name": "fullDescription"})
    full_name = attr.ib(default=None, metadata={"schema_property_name": "fullName"})
    global_message_strings = attr.ib(default=None, metadata={"schema_property_name": "globalMessageStrings"})
    guid = attr.ib(default=None, metadata={"schema_property_name": "guid"})
    information_uri = attr.ib(default=None, metadata={"schema_property_name": "informationUri"})
    is_comprehensive = attr.ib(default=None, metadata={"schema_property_name": "isComprehensive"})
    language = attr.ib(default="en-US", metadata={"schema_property_name": "language"})
    localized_data_semantic_version = attr.ib(default=None, metadata={"schema_property_name": "localizedDataSemanticVersion"})
    locations = attr.ib(default=None, metadata={"schema_property_name": "locations"})
    minimum_required_localized_data_semantic_version = attr.ib(default=None, metadata={"schema_property_name": "minimumRequiredLocalizedDataSemanticVersion"})
    notifications = attr.ib(default=None, metadata={"schema_property_name": "notifications"})
    organization = attr.ib(default=None, metadata={"schema_property_name": "organization"})
    product = attr.ib(default=None, metadata={"schema_property_name": "product"})
    product_suite = attr.ib(default=None, metadata={"schema_property_name": "productSuite"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    release_date_utc = attr.ib(default=None, metadata={"schema_property_name": "releaseDateUtc"})
    rules = attr.ib(default=None, metadata={"schema_property_name": "rules"})
    semantic_version = attr.ib(default=None, metadata={"schema_property_name": "semanticVersion"})
    short_description = attr.ib(default=None, metadata={"schema_property_name": "shortDescription"})
    supported_taxonomies = attr.ib(default=None, metadata={"schema_property_name": "supportedTaxonomies"})
    taxa = attr.ib(default=None, metadata={"schema_property_name": "taxa"})
    translation_metadata = attr.ib(default=None, metadata={"schema_property_name": "translationMetadata"})
    version = attr.ib(default=None, metadata={"schema_property_name": "version"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class ArtifactChange(object):
    """A change to a single artifact."""

    artifact_location = attr.ib()
    replacements = attr.ib()
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class Location(object):
    """A location within a programming artifact."""

    annotations = attr.ib(default=None, metadata={"schema_property_name": "annotations"})
    id = attr.ib(default=-1, metadata={"schema_property_name": "id"})
    logical_locations = attr.ib(default=None, metadata={"schema_property_name": "logicalLocations"})
    message = attr.ib(default=None, metadata={"schema_property_name": "message"})
    physical_location = attr.ib(default=None, metadata={"schema_property_name": "physicalLocation"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    relationships = attr.ib(default=None, metadata={"schema_property_name": "relationships"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class Result(object):
    """A result produced by an analysis tool."""

    message = attr.ib()
    analysis_target = attr.ib(default=None, metadata={"schema_property_name": "analysisTarget"})
    attachments = attr.ib(default=None, metadata={"schema_property_name": "attachments"})
    baseline_state = attr.ib(default=None, metadata={"schema_property_name": "baselineState"})
    code_flows = attr.ib(default=None, metadata={"schema_property_name": "codeFlows"})
    correlation_guid = attr.ib(default=None, metadata={"schema_property_name": "correlationGuid"})
    fingerprints = attr.ib(default=None, metadata={"schema_property_name": "fingerprints"})
    fixes = attr.ib(default=None, metadata={"schema_property_name": "fixes"})
    graph_traversals = attr.ib(default=None, metadata={"schema_property_name": "graphTraversals"})
    graphs = attr.ib(default=None, metadata={"schema_property_name": "graphs"})
    guid = attr.ib(default=None, metadata={"schema_property_name": "guid"})
    hosted_viewer_uri = attr.ib(default=None, metadata={"schema_property_name": "hostedViewerUri"})
    kind = attr.ib(default="fail", metadata={"schema_property_name": "kind"})
    level = attr.ib(default="warning", metadata={"schema_property_name": "level"})
    locations = attr.ib(default=None, metadata={"schema_property_name": "locations"})
    occurrence_count = attr.ib(default=None, metadata={"schema_property_name": "occurrenceCount"})
    partial_fingerprints = attr.ib(default=None, metadata={"schema_property_name": "partialFingerprints"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    provenance = attr.ib(default=None, metadata={"schema_property_name": "provenance"})
    rank = attr.ib(default=-1.0, metadata={"schema_property_name": "rank"})
    related_locations = attr.ib(default=None, metadata={"schema_property_name": "relatedLocations"})
    rule = attr.ib(default=None, metadata={"schema_property_name": "rule"})
    rule_id = attr.ib(default=None, metadata={"schema_property_name": "ruleId"})
    rule_index = attr.ib(default=-1, metadata={"schema_property_name": "ruleIndex"})
    stacks = attr.ib(default=None, metadata={"schema_property_name": "stacks"})
    suppressions = attr.ib(default=None, metadata={"schema_property_name": "suppressions"})
    taxa = attr.ib(default=None, metadata={"schema_property_name": "taxa"})
    web_request = attr.ib(default=None, metadata={"schema_property_name": "webRequest"})
    web_response = attr.ib(default=None, metadata={"schema_property_name": "webResponse"})
    work_item_uris = attr.ib(default=None, metadata={"schema_property_name": "workItemUris"})



# This file was generated by jschema_to_python version 1.1.4.

from sarif_om._sarif_log import SarifLog
from sarif_om._address import Address
from sarif_om._artifact import Artifact
from sarif_om._artifact_change import ArtifactChange
from sarif_om._artifact_content import ArtifactContent
from sarif_om._artifact_location import ArtifactLocation
from sarif_om._attachment import Attachment
from sarif_om._code_flow import CodeFlow
from sarif_om._configuration_override import ConfigurationOverride
from sarif_om._conversion import Conversion
from sarif_om._edge import Edge
from sarif_om._edge_traversal import EdgeTraversal
from sarif_om._exception import Exception
from sarif_om._external_properties import ExternalProperties
from sarif_om._external_property_file_reference import ExternalPropertyFileReference
from sarif_om._external_property_file_references import ExternalPropertyFileReferences
from sarif_om._fix import Fix
from sarif_om._graph import Graph
from sarif_om._graph_traversal import GraphTraversal
from sarif_om._invocation import Invocation
from sarif_om._location import Location
from sarif_om._location_relationship import LocationRelationship
from sarif_om._logical_location import LogicalLocation
from sarif_om._message import Message
from sarif_om._multiformat_message_string import MultiformatMessageString
from sarif_om._node import Node
from sarif_om._notification import Notification
from sarif_om._physical_location import PhysicalLocation
from sarif_om._property_bag import PropertyBag
from sarif_om._rectangle import Rectangle
from sarif_om._region import Region
from sarif_om._replacement import Replacement
from sarif_om._reporting_configuration import ReportingConfiguration
from sarif_om._reporting_descriptor import ReportingDescriptor
from sarif_om._reporting_descriptor_reference import ReportingDescriptorReference
from sarif_om._reporting_descriptor_relationship import ReportingDescriptorRelationship
from sarif_om._result import Result
from sarif_om._result_provenance import ResultProvenance
from sarif_om._run import Run
from sarif_om._run_automation_details import RunAutomationDetails
from sarif_om._special_locations import SpecialLocations
from sarif_om._stack import Stack
from sarif_om._stack_frame import StackFrame
from sarif_om._suppression import Suppression
from sarif_om._thread_flow import ThreadFlow
from sarif_om._thread_flow_location import ThreadFlowLocation
from sarif_om._tool import Tool
from sarif_om._tool_component import ToolComponent
from sarif_om._tool_component_reference import ToolComponentReference
from sarif_om._translation_metadata import TranslationMetadata
from sarif_om._version_control_details import VersionControlDetails
from sarif_om._web_request import WebRequest
from sarif_om._web_response import WebResponse



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class ThreadFlowLocation(object):
    """A location visited by an analysis tool while simulating or monitoring the execution of a program."""

    execution_order = attr.ib(default=-1, metadata={"schema_property_name": "executionOrder"})
    execution_time_utc = attr.ib(default=None, metadata={"schema_property_name": "executionTimeUtc"})
    importance = attr.ib(default="important", metadata={"schema_property_name": "importance"})
    index = attr.ib(default=-1, metadata={"schema_property_name": "index"})
    kinds = attr.ib(default=None, metadata={"schema_property_name": "kinds"})
    location = attr.ib(default=None, metadata={"schema_property_name": "location"})
    module = attr.ib(default=None, metadata={"schema_property_name": "module"})
    nesting_level = attr.ib(default=None, metadata={"schema_property_name": "nestingLevel"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    stack = attr.ib(default=None, metadata={"schema_property_name": "stack"})
    state = attr.ib(default=None, metadata={"schema_property_name": "state"})
    taxa = attr.ib(default=None, metadata={"schema_property_name": "taxa"})
    web_request = attr.ib(default=None, metadata={"schema_property_name": "webRequest"})
    web_response = attr.ib(default=None, metadata={"schema_property_name": "webResponse"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class ReportingConfiguration(object):
    """Information about a rule or notification that can be configured at runtime."""

    enabled = attr.ib(default=True, metadata={"schema_property_name": "enabled"})
    level = attr.ib(default="warning", metadata={"schema_property_name": "level"})
    parameters = attr.ib(default=None, metadata={"schema_property_name": "parameters"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    rank = attr.ib(default=-1.0, metadata={"schema_property_name": "rank"})



# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class Stack(object):
    """A call stack that is relevant to a result."""

    frames = attr.ib()
    message = attr.ib(default=None, metadata={"schema_property_name": "message"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
